@@ -13,11 +13,11 @@ def create_directories(directory_list):
             os.makedirs(path)
 
 
-def files_already_downloaded(raw_path: str, file_path_list: list) -> bool:
+def files_already_downloaded(raw_path: str, file_list: list) -> bool:
     all_files = []
     for _, _, files in os.walk(raw_path):
         all_files += files
-    for file in file_path_list:
+    for file in file_list:
         if file not in all_files:
             return False
 
